positionedBottom method

Positioned positionedBottom(
  1. double bottom
)

Positions the widget at a specific distance from the bottom edge of the stack.

This is a convenience method equivalent to calling positioned(bottom: bottom). The widget will be positioned at the specified distance from the bottom edge, while other dimensions remain unconstrained.

Parameters:

  • bottom: Distance from the bottom edge of the stack.

Returns a Positioned widget positioned from the bottom.

Example:

Stack(
  children: [
    FloatingActionButton(onPressed: () {})
      .positionedBottom(20), // 20px from bottom
    Text('Footer').positionedBottom(60), // 60px from bottom
  ],
);

Implementation

Positioned positionedBottom(double bottom) => positioned(bottom: bottom);