positionedRight method

Positioned positionedRight(
  1. double right
)

Positions the widget at a specific distance from the right edge of the stack.

This is a convenience method equivalent to calling positioned(right: right). The widget will be positioned at the specified distance from the right edge, while other dimensions remain unconstrained.

Parameters:

  • right: Distance from the right edge of the stack.

Returns a Positioned widget positioned from the right.

Example:

Stack(
  children: [
    Icon(Icons.close).positionedRight(16), // 16px from right edge
    Text('Menu').positionedRight(60),      // 60px from right edge
  ],
);

Implementation

Positioned positionedRight(double right) => positioned(right: right);