stackExpand method

Stack stackExpand({
  1. AlignmentGeometry alignment = AlignmentDirectional.topStart,
  2. TextDirection? textDirection,
  3. Clip clipBehavior = Clip.hardEdge,
})

Creates a Stack with StackFit.expand sizing behavior.

In expand mode, the stack will force all non-positioned children to be as large as the stack itself. This is useful when you want all children to fill the entire available space.

Parameters:

  • alignment: How to align the children in the stack. Defaults to AlignmentDirectional.topStart.
  • textDirection: The text direction to use when resolving alignment.
  • clipBehavior: The content clipping behavior. Defaults to Clip.hardEdge.

Returns a Stack widget with expand sizing behavior.

Implementation

Stack stackExpand({
  AlignmentGeometry alignment = AlignmentDirectional.topStart,
  TextDirection? textDirection,
  Clip clipBehavior = Clip.hardEdge,
}) =>
    stack(
      fit: StackFit.expand,
      alignment: alignment,
      textDirection: textDirection,
      clipBehavior: clipBehavior,
    );