flex3 method
Wraps the widget in a Flexible with flex value 3.
This is a convenience method equivalent to calling flex(flex: 3, fit: fit).
Takes up to three times as much space as widgets with flex value 1.
Parameters:
fit: How the child should fit within the allocated space. Defaults to FlexFit.loose.
Returns a Flexible widget with flex value 3.
Implementation
Flexible flex3([FlexFit fit = FlexFit.loose]) => flex(flex: 3, fit: fit);