wordSpacing method
Sets the word spacing for the text.
This is a convenience method equivalent to calling styled(wordSpacing: spacing).
Parameters:
spacing: The word spacing in logical pixels.
Returns a new Text widget with the specified word spacing.
Implementation
Text wordSpacing(double spacing) => styled(wordSpacing: spacing);